This is an automated email from the ASF dual-hosted git repository.

amc pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficserver.git


The following commit(s) were added to refs/heads/master by this push:
     new 2bcc9eb  Chamge src/tscpp/api/TransformationPlugin.cc to avoid error 
for -Werror=subobject-linkage .
2bcc9eb is described below

commit 2bcc9eba77703ab03b164b0c4e9ed47eac3eb672
Author: Walter Karas <[email protected]>
AuthorDate: Thu Jan 17 17:40:34 2019 -0600

    Chamge src/tscpp/api/TransformationPlugin.cc to avoid error for 
-Werror=subobject-linkage .
---
 src/tscpp/api/TransformationPlugin.cc | 31 ++++++++++++++++++-------------
 1 file changed, 18 insertions(+), 13 deletions(-)

diff --git a/src/tscpp/api/TransformationPlugin.cc 
b/src/tscpp/api/TransformationPlugin.cc
index 435e498..5d85075 100644
--- a/src/tscpp/api/TransformationPlugin.cc
+++ b/src/tscpp/api/TransformationPlugin.cc
@@ -34,28 +34,27 @@
 #define INT64_MAX (9223372036854775807LL)
 #endif
 
-using namespace atscppapi;
-using atscppapi::TransformationPlugin;
-
-namespace
+namespace atscppapi
 {
-class ResumeAfterPauseCont : public Continuation
+namespace detail
 {
-public:
-  ResumeAfterPauseCont() : Continuation() {}
+  class ResumeAfterPauseCont : public Continuation
+  {
+  public:
+    ResumeAfterPauseCont() : Continuation() {}
 
-  ResumeAfterPauseCont(Continuation::Mutex m) : Continuation(m) {}
+    ResumeAfterPauseCont(Continuation::Mutex m) : Continuation(m) {}
 
-protected:
-  int _run(TSEvent event, void *edata) override;
-};
+  protected:
+    int _run(TSEvent event, void *edata) override;
+  };
 
-} // end anonymous namespace
+} // end namespace detail
 
 /**
  * @private
  */
-struct atscppapi::TransformationPluginState : noncopyable, public 
ResumeAfterPauseCont {
+struct TransformationPluginState : noncopyable, public 
detail::ResumeAfterPauseCont {
   TSVConn vconn_;
   Transaction &transaction_;
   TransformationPlugin &transformation_plugin_;
@@ -107,8 +106,14 @@ struct atscppapi::TransformationPluginState : noncopyable, 
public ResumeAfterPau
   }
 };
 
+} // end namespace atscppapi
+
+using namespace atscppapi;
+
 namespace
 {
+using ResumeAfterPauseCont = atscppapi::detail::ResumeAfterPauseCont;
+
 void
 cleanupTransformation(TSCont contp)
 {

Reply via email to